@@ -5,7 +5,7 @@ use warnings;
 use v5.10;
 
 # ABSTRACT: Template Renderer Plugin for Mojolicious
-our $VERSION = '1.55'; # VERSION
+our $VERSION = '1.57'; # VERSION
 
 use base 'Mojolicious::Plugin';
 
@@ -38,7 +38,7 @@ Mojolicious::Plugin::TtRenderer - Template Renderer Plugin for Mojolicious
 
 =head1 VERSION
 
-version 1.55
+version 1.57
 
 =head1 SYNOPSIS
 
@@ -60,6 +60,8 @@ L<Mojolicious::Plugin::TtRenderer::Engine> directly.
 =for stopwords Bjørn
 Szász
 Árpád
+Романов
+Сергей
 
 =head1 OPTIONS
 
@@ -231,8 +233,6 @@ L<Mojolicious>,
 L<Mojolicious::Guides>, 
 L<http://mojolicious.org>.
 
-=cut
-
 =head1 AUTHOR
 
 Original author: Ask Bjørn Hansen
@@ -271,6 +271,8 @@ spleenjack
 
 uwisser
 
+Dinis Lage
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Ask Bjørn Hansen.
