@@ -13,7 +13,7 @@ use Scalar::Util 'weaken';
 use POSIX ':errno_h';
 
 # ABSTRACT: Template Toolkit renderer for Mojolicious
-our $VERSION = '1.55'; # VERSION
+our $VERSION = '1.57'; # VERSION
 
 __PACKAGE__->attr('tt');
 
@@ -21,7 +21,7 @@ sub build {
     my $self = shift->SUPER::new(@_);
     weaken($self->{app});
     $self->_init(@_);
-    return sub { $self->_render(@_) }
+    sub { $self->_render(@_) }
 }
 
 sub _init {
@@ -55,11 +55,13 @@ sub _init {
         %{$args{template_options} || {}},
     );
 
-    $config{COMPILE_DIR} //= $dir || do {
-      my $tmpdir = File::Spec->catdir(File::Spec->tmpdir, "ttr$<");
-      mkdir $tmpdir unless -d $tmpdir;
-      $tmpdir;
-    };
+    if ( !exists( $config{COMPILE_DIR} ) ) {
+        $config{COMPILE_DIR} //= $dir || do {
+          my $tmpdir = File::Spec->catdir(File::Spec->tmpdir, "ttr$<");
+          mkdir $tmpdir unless -d $tmpdir;
+          $tmpdir;
+        };
+    }
 
     $config{LOAD_TEMPLATES} =
       [Mojolicious::Plugin::TtRenderer::Provider->new(%config, renderer => $app->renderer)]
@@ -68,7 +70,7 @@ sub _init {
     $self->tt(Template->new(\%config))
       or Carp::croak "Could not initialize Template object: $Template::ERROR";
 
-    return $self;
+    $self;
 }
 
 sub _render {
@@ -84,9 +86,6 @@ sub _render {
 
     my $helper = Mojolicious::Plugin::TtRenderer::Helper->new(ctx => $c);
 
-    # Purge previous result
-    $$output = '';
-
     # fixes for t/lite_app_with_default_layouts.t
     unless ($c->stash->{layout}) {
         $c->stash->{content} ||= $c->stash->{'mojo.content'}->{content};
@@ -108,10 +107,10 @@ sub _render {
                 $self->tt->process($ret[0], @params);
             }
             elsif (not defined $ret[0]) { # not found
-                return 0;
+                return;
             }
             else { # error
-                return 0 if $! == ENOENT && (not ref $ret[0]); # not found when not blessed exception
+                return if $! == ENOENT && (not ref $ret[0]); # not found when not blessed exception
                 die $ret[0];
             }
         }
@@ -119,8 +118,6 @@ sub _render {
 
     # Error
     die $self->tt->error unless $ok;
-
-    return 1;
 }
 
 1;    # End of Mojolicious::Plugin::TtRenderer::Engine
@@ -150,7 +147,7 @@ sub AUTOLOAD {
 
     die qq/Unknown helper: $method/ unless $self->ctx->app->renderer->helpers->{$method};
 
-    return $self->ctx->$method(@_);
+    $self->ctx->$method(@_);
 }
 
 1;
@@ -173,7 +170,7 @@ sub new {
     my $self = $class->SUPER::new(%params);
     $self->renderer($renderer);
     weaken($self->{renderer});
-    return $self;
+    $self;
 }
 
 sub renderer      { @_ > 1 ? $_[0]->{renderer}      = $_[1] : $_[0]->{renderer} }
@@ -216,7 +213,7 @@ sub _template_content {
         $data = '';
         $error = "$path: not found";
     }
-    return wantarray ? ($data, $error, time) : $data;
+    wantarray ? ($data, $error, time) : $data;
 }
 
 1;
@@ -233,7 +230,7 @@ Mojolicious::Plugin::TtRenderer::Engine - Template Toolkit renderer for Mojolici
 
 =head1 VERSION
 
-version 1.55
+version 1.57
 
 =head1 SYNOPSIS
 
@@ -276,6 +273,8 @@ come with Mojolicious.
 =for stopwords Bjørn
 Szász
 Árpád
+Романов
+Сергей
 
 =head1 RENDERING
 
@@ -334,8 +333,6 @@ L<Mojolicious>,
 L<Mojolicious::Guides>, 
 L<http://mojolicious.org>.
 
-=cut
-
 =head1 AUTHOR
 
 Original author: Ask Bjørn Hansen
@@ -374,6 +371,8 @@ spleenjack
 
 uwisser
 
+Dinis Lage
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Ask Bjørn Hansen.
